/************************************************************************/
/* Author: 	Hirotaka Miura.						*/
/* Contact: 	Hirotaka.Miura@gmail.com.				*/
/************************************************************************/

/************************************************************************/
/* 05/05/2011: 	Modified.						*/
/* 04/24/2011: 	Previouly modified.					*/
/* 04/22/2011: 	Created.						*/
/************************************************************************/

/************************************************************************/
/* Program: 	bfs_sp().						*/
/* Function: 	Breadth-depth search single-source shortest-path algthm.*/					*/
/************************************************************************/
mata:
struct matrix_struct scalar bfs_sp(real matrix E, 
  | string scalar nodots){
  /* Declare variables.							*/
  struct matrix_struct scalar z /* Return structure.			*/
  real matrix A /* Adjacency list.					*/
  real matrix D /* Distance matrix.					*/
  real matrix W /* Weight matrix.					*/
  real matrix L /* Leaf vertex matrix.					*/  
  real vector l /* Adjacency list.					*/  
  real vector q /* Queue vector.					*/
  real scalar r /* Read pointer.					*/
  real scalar w /* Write pointer.					*/
  real scalar v /* Current vertex.					*/
  real scalar d /* Distance from source vertex.				*/
  real scalar j /* Column counter.					*/  
  real scalar s /* Source vertex.					*/
  real scalar m /* Total number of nodes in network.			*/
  real scalar f /* Leaf counter.					*/  
  string scalar o /* Status display string.				*/
  /**********************************************************************/
  /* Begin program.							*/
  /**********************************************************************/
  /* Obtain adjacency list.						*/
  z=adjacency_list(E); A=z.X1  
  /* Obtain total number of nodes in network.				*/
  m=rows(A)  
  /***** Inform user of program starting.				*/
  o="noisily display "+`""""'; stata(o); displayflush()
  o="Breadth-first search algorithm ("+strofreal(m)+" vertices)"
  o="noisily display "+`"""'+o+`"""'
  stata(o); displayflush()
  /* Display dots unless specified not to.				*/
  if(nodots==""){
    o="----+--- 1 ---+--- 2 ---+--- 3 ---+--- 4 ---+--- 5"
    o="noisily display "+`"""'+o+`"""'
    stata(o); displayflush() 
  }
  /***** Setup for loop.						*/
  /* Initialize matrices.						*/
  D=J(m,m,.); W=J(m,m,.); L=J(m,m,.)
  /***** Loop through all the nodes.					*/
  for(s=1;s<=m;s++){
    /* Insert source node entry.					*/
    D[s,s]=0; W[s,s]=1
    /* Initiate queue array with source vertex.				*/
    q=J(1,m,.); q[1]=s
    /* Set read and write pointers.					*/
    r=1; w=2
    /* Loop while read and write pointers are not equal to each other.	*/
    while(r!=w){    
      /* Read vertex pointed to by read pointer.			*/
      v=q[r]
      /* Increment read pointer.					*/
      ++r
      /* Find distance from source vertex for vertex "v."		*/
      d=D[s,v]    
      /* Obtain adjacency list of out-neighbors of vertex "v."		*/
      l=A[v,.]
      /* Re-set leaf counter.						*/
      f=0      
      /* Loop through out-neighbors of vertex "v."			*/
      for(j=1;j<=nonmissing(l);j++){
        /* If neighbor already has assigned distance, 			*/
        /* assign additional weight.					*/
        if(D[s,l[j]]==d+1){
          /* Increment own weight with vertex "v"'s weight.		*/
          W[s,l[j]]=W[s,l[j]]+W[s,v]
          /* Indicate neighbor of vertex "v" not a leaf.		*/
          ++f
        }	
	/* If distance hasn't been assigned, assign distance.		*/
	else if(D[s,l[j]]==.){
	  /* Assign distance.						*/
	  D[s,l[j]]=d+1
	  /* Input neighbor into queue vector; increment write pointer.	*/
	  q[w]=l[j]; ++w
          /* Assign vertex "v"'s weight to neighbor.			*/
          W[s,l[j]]=W[s,v]
          /* Indicate neighbor of vertex "v" not a leaf.		*/
	  ++f	  
	}
      }
      /* Indicate if vertex "v" is a leaf or not.			*/
      if(f==0){
        L[s,v]=1
      }      
    }    
    /* Display status unless specified not to.				*/
    if(nodots=="") display_status(m,s)
  }
  /* Notify program is over.						*/
  o="Breadth-first search algorithm completed"
  o="noisily display "+`"""'+o+`"""'
  stata(o); displayflush()  
  /* Return matrices.							*/
  z.X1=D; z.X2=W; z.X3=L; z.X4=A
  return(z)
}    
end





