{smcl}
{* *! Stata Graph Library version 1.1.2  06jun2011}{...}
{cmd:help network}
{hline}

{title:Title}

{p2colset 5 16 25 2}{...}
{p2col:{hi:network} {hline 2}}Network Analysis{p_end}
{p2colreset}{...}


{title:Syntax}

{p 8 14 2}
{cmd:network} 
  {varname:1}
  {varname:2}
  [{it:if}]
  [{it:in}]{cmd:,}
  {opt m:easure(network_measure)}
  [{it:options}]

{phang} where {it:network_measure} can be one of

{p2colset 9 31 19 2}{...}
{p2col:{cmdab:a:djacency}} adjacency matrix{p_end}
{p2col:| {cmdab:d:istance}} distance matrix{p_end}
{p2col:| {cmdab:p:ath}} path matrix{p_end}
{p2col:| {cmdab:b:etweenness}} betweenness centrality{p_end}
{p2col:| {cmdab:c:lustering}} local and overall/average clustering coefficients{p_end}
{p2col:| {cmdab:e:igenvector}} eigenvector centrality{p_end}
{p2col:| {cmdab:m:axalpha}} maximum free parameter alpha {p_end}
{p2col:| {cmdab:k:atzbonacich}} Katz-Bonacich centrality.{p_end}
{p2colreset}{...}

{marker options}{...}
{synoptset 25}{...}
{synopthdr}
{synoptline}
{synopt :{opt m:easure(network_measure)}}specify network measure to compute{p_end}
{synopt :{opt n:ame(mata_mname [...])}}specify Mata matrix to store results{p_end}
{synopt :{opt w:eight(weightvar)}}specify numeric edge weight variable{p_end}
{synopt :{opt l:abel(var_prefix [...])}}request vertex labels be returned to Stata{p_end}
{synopt :{opt di:rected}}specify directed edges{p_end}
{synopt :{opt nod:ots}}request status dots be suppressed{p_end}
{synopt :{opt i:nfinity(real)}}replace missing distances with {it:real}{p_end}
{synopt :{opt p:ower}}implement power iteration algorithm{p_end}
{synopt :{opt not:ranspose}}do not transpose adjacency matrix{p_end}
{synopt :{opt a:lpha(real)}}specify free parameter for Katz-Bonacich centrality calculation{p_end}
{synopt :{opt b:eta(beta_varlist)}}specify exogenous factors for Katz-Bonacich centrality calculation{p_end}
{synoptline}
{phang}See {helpb netsummarize} for features available after computation.


{title:Description}

{p 4 4 2}
{cmd:network} generates matrices, centrality measures, and clustering coefficients for network analysis.


{title:Options}

{dlgtab:Main}

{phang}
{opt measure(network_measure)} specifies the network measure to be computed. This option is required.

{phang}
{opt name(mata_mname [, replace])} specifies the Mata matrix name to store results. {cmd:replace} requests existing
Mata matrix be overwritten.

{phang}
{opt weight(weightvar)} specifies a numeric edge weight variable. By default, edge weights are set to one for all
vertices internally and thus an unweighted network is assumed.

{phang}
{opt label(var_prefix [, replace])} requests vertex labels be returned to Stata with variable names prefixed with
{it:var_prefix} and suffixed with {cmd:_source} and {cmd:_target} for {varname:_source} and {varname:_target}, respectively.
{cmd:replace} requests existing same-named label variables be overwritten.

{phang}
{opt directed} specifies directed edges. By default, edges are assumed to be undirected.

{phang}
{opt nodots} requests that status dots be suppressed.

{phang}
{opt infinity(real)} specifies a real number to replace missing or "infinite" distances. Scalars returned in {cmd:e()}
refer to matrix before replacement. {opt name(mata_mname)} contains distance matrix after replacement. The
option only applies when generating distance matrix.

{phang}
{cmd:power} requests the power method be implemented in computing eigenvector centrality, maximum alpha, and
Katz-Bonacich centrality. By default, Mata's built-in linear algebra functions are used.

{phang}
{cmd:notranspose} requests that the adjacency matrix not be transposed when computing eigenvector and Katz-Bonacich centralities. By default, adjacency matrix is transposed.

{phang}
{opt alpha(real)} specifies a real number for the free parameter in Katz-Bonacich centrality calculation. By
default, alpha is set to one.

{phang}
{opt beta(beta_varlist)} specifies exogenous factors for the Katz-Bonacich centrality measure. By default, exogenous factors are set to one for all vertices.


{title:Remarks}

{pstd}
{cmd:network} is a wrapper for class {cmd:network_measure}, which in turn is a wrapper for functions compiled in
the Stata Graph Library (SGL). As SGL functions are each designed to carry out specific tasks, a class wrapper is useful in providing
additional organization. See {helpb m2_class:[M-2] class}.

{pstd}
{cmd:network} does not store results as Stata matrices. See {helpb mf_st_matrix:[M-5] st_matrix()} on how to transfer Mata matrices
from/to Stata.

{pstd}
{varname:_source} and {varname:_target} must either be both numeric or both string type variables. When working with an undirected network, the notion of {it:source} and {it:target} does not matter. Furthermore, reciprocal
relations for undirected networks do not need to be defined (OK if it is) when using the {cmd:network} command in Stata. {it:weightvar} and {it:beta_varlist} must be type numeric with variables of {it:beta_varlist}
corresponding to the order of {varname:_source} and {varname:_target}. 

{pstd}
{cmd:network} will return an error code of 198 and exit if parallel edges, self-loops, and/or non-positive weights are encountered. Otherwise isolated vertices, edges with missing weights (if {it:weightvar} specified), and vertices with missing
beta exogenous factor (if {it:beta_varlist} specified) will automatically be excluded from the analysis sample.

{pstd}
The recommended approach to using Katz-Bonacich function is to first obtain maximum alpha using
{cmd:maxalpha()} and then based on the returned value, specify {cmd:alpha()} option while calling {cmd:katzbonacich()}. Note that singular or near-singular matrices pose computational problems and thus {cmd:eigenvector()}, {cmd:maxalpha()},
and {cmd:katzbonacich()} functions may not converge in such cases.

{pstd}
{cmd: ..., measure(clustering)} {opt name(mata_mname)} stores {it:mata_mname} matrix in Mata with columns one
through four corresponding to local clustering coefficients based on arithmetic mean, geometric mean, maximum, and minimum, respectively.


{title:Example:  Workflow using {cmd:pajek2stata}, {cmd:network}, and {cmd:netsummarize}}

{pstd}Transfer Pajek's .net file into Stata using Rense Corten's {helpb pajek2stata}.{p_end}
{phang2}{com}. pajek2stata using florentine_marriages.net, name(X) clear replace{p_end}
{phang2}{com}. destring var1, replace{p_end}
{txt}
{pstd}Generate new value-label.  See {helpb mf_st_vlexists:[M-5] st_vlexists()}.{p_end}
{phang2}{com}. mata st_vlmodify("vertex_label",st_data(.,"var1"),st_sdata(.,"var2")){p_end}
{res}{txt}
{pstd}Drop vertex label variables and add new variables.{p_end}
{phang2}{com}. drop var1 var2{p_end}
{phang2}{com}. mata (void) st_addvar("double",("source","target")){p_end}
{res}{txt}
{pstd}Add observations.{p_end}
{phang2}{com}. mata st_addobs(rows(X)){p_end}
{res}{txt}
{pstd}Store edge list in Stata.{p_end}
{phang2}{com}. mata st_store(.,("source","target"),X){p_end}
{res}{txt}
{pstd}Assign value label to variables.{p_end}
{phang2}{com}. label values source target vertex_label{p_end}
{txt}
{pstd}Generate degree centrality.{p_end}
{phang2}{com}. network source target, measure(adjacency) name(A,replace){p_end}
{phang2}{com}. netsummarize A/(rows(A)-1), generate(degree) statistic(rowsum){p_end}
{res}{txt}
{pstd}Generate closeness centrality.{p_end}
{phang2}{com}. network source target, measure(distance) name(D,replace){p_end}
{phang2}{com}. netsummarize (rows(D)-1):/rowsum(D), generate(closeness) statistic(rowsum){p_end}
{res}{txt}
{pstd}Generate betweenness centrality.{p_end}
{phang2}{com}. network source target, measure(betweenness) name(b,replace){p_end}
{phang2}{com}. netsummarize b/((rows(b)-1)*(rows(b)-2)), generate(betweenness) statistic(rowsum){p_end}
{res}{txt}
{pstd}Generate eigenvector centrality.{p_end}
{phang2}{com}. network source target, measure(eigenvector) name(e,replace){p_end}
{phang2}{com}. netsummarize e, generate(eigenvector) statistic(rowsum){p_end}
{txt}

{title:Example:  Time series analysis}

{pstd}Load IMF CPIS dataset.{p_end}
{phang2}{com}. use imfcpis, clear{p_end}
{res}{txt}
{pstd}Compute and list clustering coefficients for each year.{p_end}
{phang2}{com}. forvalues i=2001/2009{c -(}{p_end}
{phang2}{com}. network source target if year==`i', measure(clustering) directed weight(weight){p_end}
{phang2}{com}. matrix list e(cc){p_end}
{phang2}{com}. {c )-}{p_end}
{txt}

{title:Example:  Relational to panel dataset}

{pstd}Load IMF CPIS dataset.{p_end}
{phang2}{com}. use imfcpis, clear{p_end}
{txt}
{pstd}Drop year 2001 - World Bank data is available from 2002 to 2009.{p_end}
{phang2}{com}. drop if year==2001{p_end}
{txt}
{pstd}Compute ineccentricity.{p_end}
{phang2}{com}. forvalues i=2002/2009{c -(}{p_end}
{phang2}{com}. network source target if year==`i', measure(distance) name(D`i',replace) weight(weight) directed nodots{p_end}
{phang2}{com}. netsummarize D`i', generate(ineccentricity`i') statistic(colmax){p_end}
{phang2}{com}. {c )-}{p_end}
{txt}
{pstd}Transfer results to one variable per source and target.{p_end}
{phang2}{com}. generate ineccentricity_source=.{p_end}
{phang2}{com}. label variable ineccentricity_source "ineccentricity"{p_end}
{phang2}{com}. generate ineccentricity_target=.{p_end}
{phang2}{com}. label variable ineccentricity_target "ineccentricity"{p_end}
{phang2}{com}. forvalues i=2002/2009{c -(}{p_end}
{phang2}{com}. quietly replace ineccentricity_source=ineccentricity`i'_source if year==`i'{p_end}
{phang2}{com}. quietly replace ineccentricity_target=ineccentricity`i'_target if year==`i'{p_end}
{phang2}{com}. {c )-}{p_end}
{phang2}{com}. drop *eccentricity200*{p_end}
{txt}
{pstd}Compute eigenvector centrality.{p_end}
{pstd}Generate and use real investment as edge weight.{p_end}
{phang2}{com}. generate realinvestment=investment/(uscpi/100){p_end}
{phang2}{com}. forvalues i=2002/2009{c -(}{p_end}
{phang2}{com}. network source target if year==`i', measure(eigenvector) name(e`i',replace) weight(realinvestment) directed nodots{p_end}
{phang2}{com}. netsummarize e`i', generate(eigenvector`i') statistic(rowsum){p_end}
{phang2}{com}. {c )-}{p_end}
{txt}
{pstd}Transfer results to one variable per source and target.{p_end}
{phang2}{com}. generate eigenvector_source=.{p_end}
{phang2}{com}. label variable eigenvector_source "eigenvector"{p_end}
{phang2}{com}. generate eigenvector_target=.{p_end}
{phang2}{com}. label variable eigenvector_target "eigenvector"{p_end}
{phang2}{com}. forvalues i=2002/2009{c -(}{p_end}
{phang2}{com}. quietly replace eigenvector_source=eigenvector`i'_source if year==`i'{p_end}
{phang2}{com}. quietly replace eigenvector_target=eigenvector`i'_target if year==`i'{p_end}
{phang2}{com}.  {c )-}{p_end}
{phang2}{com}. drop *eigenvector200*{p_end}
{phang2}{com}. rename ineccentricity_target ineccentricity{p_end}
{phang2}{com}. rename eigenvector_target eigenvector{p_end}
{txt}
{pstd}Collapse by target country and year.{p_end}
{phang2}{com}. #d;{p_end}
{phang2}{com}. collapse (sum) weight (sum) investment (sum) realinvestment{p_end}
{phang2}{com}>     (mean) uscpi (mean) ineccentricity (mean) eigenvector{p_end}
{phang2}{com}>     , by(target year){p_end}
{phang2}{com}>   ;{p_end}
{phang2}{com}. #d cr{p_end}
{txt}
{pstd}Merge in World Bank data.  Keep matched observations.{p_end}
{phang2}{com}. rename target country{p_end}
{phang2}{com}. label variable country "Country name"{p_end}
{phang2}{com}. merge 1:1 country year using worldbank, keep(matched) nogenerate{p_end}
{txt}
{pstd}Declare data to be a panel.{p_end}
{phang2}{com}. encode country, generate(country2){p_end}
{phang2}{com}. xtset country2 year{p_end}
{txt}

{title:Saved results}

{pstd}
{opt network, measure(network_measure)}, where {it:network_measure} is equal to one of {cmd:adjacency}, {cmd:distance}, {cmd:path}, {cmd:betweenness}, or {cmd:katzbonacich}, saves the following in {cmd:e()}:

{synoptset 20 tabbed}{...}
{p2col 5 20 24 2: Scalars}{p_end}
{synopt:{cmd:e(vertices)}}number of vertices{p_end}
{synopt:{cmd:e(edges)}}number of edges{p_end}
{synopt:{cmd:e(mean)}}mean(mean({cmd:X})'){p_end}
{synopt:{cmd:e(min)}}min({cmd:X}){p_end}
{synopt:{cmd:e(max)}}max({cmd:X}){p_end}
{synopt:{cmd:e(sum)}}sum({cmd:X}){p_end}
{synopt:{cmd:e(missing)}}missing({cmd:X}){p_end}
{synopt:{cmd:e(nonmissing)}}nonmissing({cmd:X}){p_end}

{pstd}
{cmd:network, measure(clustering)} saves the following in {cmd:e()}:

{synoptset 20 tabbed}{...}
{p2col 5 20 24 2: Scalars}{p_end}
{synopt:{cmd:e(vertices)}}number of vertices{p_end}
{p2col 5 20 24 2: Matrices}{p_end}
{synopt:{cmd:e(cc)}}overall and average clustering coefficients{p_end}

{pstd}
{cmd:network, measure(eigenvector)} saves the following in {cmd:e()}:

{synoptset 20 tabbed}{...}
{p2col 5 20 24 2: Scalars}{p_end}
{synopt:{cmd:e(vertices)}}number of vertices{p_end}
{synopt:{cmd:e(edges)}}number of edges{p_end}
{synopt:{cmd:e(l)}}dominant eigenvalue{p_end}
{synopt:{cmd:e(mean)}}mean(mean({cmd:X})'){p_end}
{synopt:{cmd:e(min)}}min({cmd:X}){p_end}
{synopt:{cmd:e(max)}}max({cmd:X}){p_end}
{synopt:{cmd:e(sum)}}sum({cmd:X}){p_end}
{synopt:{cmd:e(missing)}}missing({cmd:X}){p_end}
{synopt:{cmd:e(nonmissing)}}nonmissing({cmd:X}){p_end}

{pstd}
{cmd:network, measure(maxalpha)} saves the following in {cmd:e()}:

{synoptset 20 tabbed}{...}
{p2col 5 20 24 2: Scalars}{p_end}
{synopt:{cmd:e(vertices)}}number of vertices{p_end}
{synopt:{cmd:e(edges)}}number of edges{p_end}
{synopt:{cmd:e(alpha_max)}}maximum alpha{p_end}

{pstd}
In addition, all network measures return the following in {cmd:e()}:

{p2col 5 20 24 2: Macros}{p_end}
{synopt:{cmd:e(cmd)}}network{p_end}
{synopt:{cmd:e(cmdline)}}command as typed{p_end}
{synopt:{cmd:e(source)}}source vertex variable{p_end}
{synopt:{cmd:e(target)}}target vertex variable{p_end}
{synopt:{cmd:e(measure)}}network measure{p_end}
{synopt:{cmd:e(edge)}}{cmd:unweighted} or {cmd:weighted}{p_end}
{synopt:{cmd:e(network)}}{cmd:undirected} or {cmd:directed}{p_end}


{title:Reference}

{phang}
Batagelj, V., and A. Mrvar. 2010. Pajek. {browse "http://pajek.imfm.si/doku.php?id=download"}.

{phang} Butts, C. T. 2010. sna: Tools for Social Network 
Analysis. R package version 2.1-0. 

{phang}
Corten, R. 2010. PAJEK2STATA: Stata module to import network data in Pajek's.net format. Statistical
Software Components, Boston College Department of Economics.

{phang} Csardi, G., and T. Nepusz. 2006. The igraph software 
package for complex network research. InterJournal Complex 
Systems: 1695.

{phang} Gleich, D. 2008. MatlabBGL. 
{browse "http://www.mathworks.com/matlabcentral/fileexchange/10922"}. 

{phang}
International Monetary Fund. 2007.
{browse "http://www.imf.org/external/np/sta/pi/datarsl.htm"}.
Coordinated Portfolio Investment Survey (CPIS) Data.  Retrieved November, 2010. 

{phang}
Padgett, J. F., and C. K. Ansell. 1993. Robust action and the rise of the Medici, 1400-1434. The American
Journal of Sociology 98(6): 1259-1319.

{phang} Siek, J., L.-Q. Lee, and A. Lumsdaine. 2001. BGL. 
{browse "http://www.boost.org/doc/libs/"}. 

{phang}
World Bank. 2010. Worldwide Governance Indicators (WGI). {browse "http://data.worldbank.org/data-catalog/worldwide-governance-indicators"}.

{phang}
---. 2011. World Development Indicators (WDI). {browse "http://data.worldbank.org/data-catalog/world-development-indicators"}.


{title:Acknowledgement}

{pstd} I would like to give special thanks to Phil Schumm for 
providing me with guidance on the structure of the program and 
Rense Corten for his valuable feedbacks on the program and the 
initial draft paper. I thank the reviewers at {it:Stata Journal} for helping me improve the program and the 
documentation. I am grateful for Siek et al. (2001, Boost Graph 
Library), Gleich (2008, MatlabBGL), Butts (2010, sna), and 
Csardi and Nepusz (2006, igraph) for making available their 
programs and source codes. I would like to express my profound 
gratitude to Galina Hale for introducing me to network analysis 
and supporting me throughout my work on this project. 


{title:Author}

{phang}
Hirotaka Miura, Economic Research Department, Federal Reserve Bank of San Francisco, San Francisco, CA. 


{title:Also see}

{psee}
{space 2}Help:  {helpb netsummarize}, {helpb pajek2stata}, {helpb stata2pajek}, {helpb netplot}, {helpb mata}
{p_end}









